==> App-lcpan-0.14.tar.gz: App-lcpan-0.14/lib/App/lcpan/Cmd/authors_by_mod_count.pm <==
package App::lcpan::Cmd::authors_by_mod_count;

# XXX fix query (too slow)

our $DATE = '2015-04-07'; # DATE
our $VERSION = '0.14'; # VERSION

use 5.010;
use strict;
use warnings;

require App::lcpan;

our %SPEC;

$SPEC{':package'} = {
    v => 1.1,
    summary => "'authors-by-mod-count' command",
};

$SPEC{'handle_cmd'} = {
    v => 1.1,
    summary => 'List authors ranked by number of modules',
    args => {
        %App::lcpan::common_args,
    },
    result_naked=>1,
};
sub handle_cmd {
    my %args = @_;

    App::lcpan::_set_args_default(\%args);
    my $cpan = $args{cpan};
    my $index_name = $args{index_name};

    my $dbh = App::lcpan::_connect_db('ro', $cpan, $index_name);

    my $sql = "SELECT
  cpanid id,
  (SELECT COUNT(*) FROM module WHERE file_id IN (SELECT id FROM file WHERE cpanid=a.cpanid)) AS mod_count
FROM author a
ORDER BY mod_count DESC
";

    my @res;
    my $sth = $dbh->prepare($sql);
    $sth->execute();
    while (my $row = $sth->fetchrow_hashref) {
        push @res, $row;
    }
    \@res;
}

1;
# ABSTRACT: 'authors-by-mod-count' command

__END__

=pod

=encoding UTF-8

=head1 NAME

App::lcpan::Cmd::authors_by_mod_count - 'authors-by-mod-count' command

=head1 VERSION

This document describes version 0.14 of App::lcpan::Cmd::authors_by_mod_count (from Perl distribution App-lcpan), released on 2015-04-07.

=head1 FUNCTIONS


=head2 handle_cmd(%args) -> any

List authors ranked by number of modules.

Arguments ('*' denotes required arguments):

=over 4

=item * B<cpan> => I<str>

Location of your local CPAN mirror, e.g. /path/to/cpan.

Defaults to C<~/cpan>.

=item * B<index_name> => I<str> (default: "index.db")

Filename of index.

=back

Return value:  (any)

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-lcpan>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> App-lcpan-0.16.tar.gz: App-lcpan-0.16/lib/App/lcpan/Cmd/authors_by_mod_count.pm <==
package App::lcpan::Cmd::authors_by_mod_count;

our $DATE = '2015-04-12'; # DATE
our $VERSION = '0.16'; # VERSION

use 5.010;
use strict;
use warnings;

require App::lcpan;

our %SPEC;

$SPEC{':package'} = {
    v => 1.1,
    summary => "'authors-by-mod-count' command",
};

$SPEC{'handle_cmd'} = {
    v => 1.1,
    summary => 'List authors ranked by number of modules',
    args => {
        %App::lcpan::common_args,
    },
};
sub handle_cmd {
    my %args = @_;

    App::lcpan::_set_args_default(\%args);
    my $cpan = $args{cpan};
    my $index_name = $args{index_name};

    my $dbh = App::lcpan::_connect_db('ro', $cpan, $index_name);

    my $sql = "SELECT
  cpanid author,
  COUNT(*) AS mod_count
FROM module m
GROUP BY cpanid
ORDER BY mod_count DESC
";

    my @res;
    my $sth = $dbh->prepare($sql);
    $sth->execute();
    while (my $row = $sth->fetchrow_hashref) {
        push @res, $row;
    }
    my $resmeta = {};
    $resmeta->{format_options} = {any=>{table_column_orders=>[[qw/author mod_count/]]}};
    [200, "OK", \@res, $resmeta];
}

1;
# ABSTRACT: 'authors-by-mod-count' command

__END__

=pod

=encoding UTF-8

=head1 NAME

App::lcpan::Cmd::authors_by_mod_count - 'authors-by-mod-count' command

=head1 VERSION

This document describes version 0.16 of App::lcpan::Cmd::authors_by_mod_count (from Perl distribution App-lcpan), released on 2015-04-12.

=head1 FUNCTIONS


=head2 handle_cmd(%args) -> [status, msg, result, meta]

List authors ranked by number of modules.

Arguments ('*' denotes required arguments):

=over 4

=item * B<cpan> => I<str>

Location of your local CPAN mirror, e.g. /path/to/cpan.

Defaults to C<~/cpan>.

=item * B<index_name> => I<str> (default: "index.db")

Filename of index.

=back

Returns an enveloped result (an array).

First element (status) is an integer containing HTTP status code
(200 means OK, 4xx caller error, 5xx function error). Second element
(msg) is a string containing error message, or 'OK' if status is
200. Third element (result) is optional, the actual result. Fourth
element (meta) is called result metadata and is optional, a hash
that contains extra information.

Return value:  (any)

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-lcpan>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
